@@ -44,7 +44,7 @@ calendar_clicked (GtkWidget* calendar, gpointer data)
     hildon_calendar_get_date(HILDON_CALENDAR(calendar),&year,&month,&day);
     hildon_date_button_set_date(HILDON_DATE_BUTTON(mycalendar->date_picker),year,month,day);
 #ifdef MY_BUILD
-    const gchar const *work[]={"休班第二天","中班","白班，夜班","休班第一天"};
+    const gchar const *work[]={"休班第一天","休班第二天","中班","白班，夜班"};
     GDate *first = g_date_new_dmy(1,1,1970);
     GDate *end = g_date_new_dmy(day,month+1,year);
     gint index = g_date_days_between(first,end)%4;
