@@ -187,7 +187,6 @@ hhc_applet_init (HhcApplet *applet)
   alarm_action_t *act = 0;
   cookie_t *list = 0;
   cookie_t cookie = 0;
-  alarm_event_t *eve = 0;
  
   if( (list = alarmd_event_query(0,0, 0,0, "Lunar")) == 0 )
   {
@@ -195,27 +194,18 @@ hhc_applet_init (HhcApplet *applet)
     goto cleanup;
   }
   int i;
-  for( i = 0; (cookie = list[i]) != 0; ++i )
+  for( i = 0; list[i] != 0; ++i )
   {
-    alarm_event_delete(eve);
- 
-    if( (eve = alarmd_event_get(cookie)) == 0 )
-    {
-      //printf("unable to get details for cookie=%ld\n", (long)cookie);
-      continue;
-    }
- 
-    //printf("cookie: %ld, %s", cookie, ctime(&eve->trigger));
-    alarmd_event_del(cookie);
+    if(i) alarmd_event_del(cookie);
+    else cookie = list[i];
   }
  
   cleanup:
     free(list);
-    alarm_event_delete(eve);
  
   /* AlarmD will return a unique "alarm cookie" if successful; you can use this
    * later to identify and manipulate your alarm, or just ignore it. */
- 
+  if(!cookie){
   newEvent = alarm_event_create();
   alarm_event_set_alarm_appid(newEvent, "Lunar");
   alarm_event_set_title(newEvent, "LunarCalendar");
@@ -224,8 +214,8 @@ hhc_applet_init (HhcApplet *applet)
   newEvent->recur_count = -1;
 
   recur = alarm_event_add_recurrences(newEvent,1);
-  recur->mask_min |= 1;
-  recur->mask_hour |= 1;
+  recur->mask_min |= 1; // 1<<0
+  recur->mask_hour |= 1; // 1<<0
   recur->mask_mday |= ALARM_RECUR_MDAY_ALL;
   recur->special |= ALARM_RECUR_SPECIAL_NONE;
  
@@ -237,8 +227,9 @@ hhc_applet_init (HhcApplet *applet)
   alarm_action_set_dbus_name(act, "update");
  
   priv->resultCookie = alarmd_event_add(newEvent);
+  alarm_recur_delete(recur);
   alarm_event_delete(newEvent);
-
+  }
   gtk_widget_show (label);
 
   gtk_container_add (GTK_CONTAINER (applet), label);
